<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>ArtisticSolidColor</name>
    <message>
        <source>Irregular</source>
        <translation>不规则</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>水平偏移</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>垂直偏移</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>杂色</translation>
    </message>
</context>
<context>
    <name>FlowLineStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>扩展</translation>
    </message>
    <message>
        <source>Width Scale</source>
        <translation>宽度比</translation>
    </message>
    <message>
        <source>Straighten Ends</source>
        <translation>拉直末端</translation>
    </message>
    <message>
        <source>Flow Line</source>
        <translation>跟随线</translation>
    </message>
</context>
<context>
    <name>MovingSolidColor</name>
    <message>
        <source>Offset</source>
        <translation>偏移</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>水平偏移</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>垂直偏移</translation>
    </message>
</context>
<context>
    <name>OutlineViewerStyle</name>
    <message>
        <source>OutlineViewer(OnlyDebug)</source>
        <translation>轮廓线查看器(仅调试)</translation>
    </message>
    <message>
        <source>Control Point</source>
        <translation>控制点</translation>
    </message>
    <message>
        <source>Center Line</source>
        <translation>中心线</translation>
    </message>
    <message>
        <source>Outline Mode</source>
        <translation>轮廓模式</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <source>distance</source>
        <translation>距离</translation>
    </message>
</context>
<context>
    <name>ShadowStyle</name>
    <message>
        <source>Hatched Shading</source>
        <translation>排线阴影</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>长度</translation>
    </message>
</context>
<context>
    <name>ShadowStyle2</name>
    <message>
        <source>Plain Shadow</source>
        <translation>平涂阴影</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>TAirbrushRasterStyle</name>
    <message>
        <source>Airbrush</source>
        <translation>喷枪</translation>
    </message>
    <message>
        <source>Blur value</source>
        <translation>模糊量</translation>
    </message>
</context>
<context>
    <name>TBiColorStrokeStyle</name>
    <message>
        <source>Shade</source>
        <translation>阴影</translation>
    </message>
</context>
<context>
    <name>TBlendRasterStyle</name>
    <message>
        <source>Blend</source>
        <translation>混合</translation>
    </message>
</context>
<context>
    <name>TBlendStrokeStyle2</name>
    <message>
        <source>Fade</source>
        <translation>淡化</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>边界淡化</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>淡入</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>淡出</translation>
    </message>
</context>
<context>
    <name>TBraidStrokeStyle</name>
    <message>
        <source>Plait</source>
        <translation>编织</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>卷曲</translation>
    </message>
</context>
<context>
    <name>TBubbleStrokeStyle</name>
    <message>
        <source>Bubbles</source>
        <translation>泡泡</translation>
    </message>
</context>
<context>
    <name>TChainStrokeStyle</name>
    <message>
        <source>Chain</source>
        <translation>链条</translation>
    </message>
</context>
<context>
    <name>TChalkFillStyle</name>
    <message>
        <source>Chalk</source>
        <translation>粉笔</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>点的大小</translation>
    </message>
</context>
<context>
    <name>TChalkStrokeStyle2</name>
    <message>
        <source>Chalk</source>
        <translation>粉笔</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>边界淡化</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>淡入</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>淡出</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>杂色</translation>
    </message>
</context>
<context>
    <name>TCheckedFillStyle</name>
    <message>
        <source>Square</source>
        <translation>格子纹</translation>
    </message>
    <message>
        <source>Horiz Dist</source>
        <translation>水平距离</translation>
    </message>
    <message>
        <source>Horiz Angle</source>
        <translation>水平角度</translation>
    </message>
    <message>
        <source>Vert Dist</source>
        <translation>垂直距离</translation>
    </message>
    <message>
        <source>Vert Angle</source>
        <translation>垂直角度</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>厚度</translation>
    </message>
</context>
<context>
    <name>TChessFillStyle</name>
    <message>
        <source>Chessboard</source>
        <translation>棋盘格</translation>
    </message>
    <message>
        <source>Horiz Size</source>
        <translation>水平大小</translation>
    </message>
    <message>
        <source>Vert Size</source>
        <translation>垂直大小</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
</context>
<context>
    <name>TCircleStripeFillStyle</name>
    <message>
        <source>Concentric</source>
        <translation>同心圆</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>水平位置</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>垂直位置</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>TCrystallizeStrokeStyle</name>
    <message>
        <source>Tulle</source>
        <translation>薄纱</translation>
    </message>
    <message>
        <source>Crease</source>
        <translation>折痕</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>不透明度</translation>
    </message>
</context>
<context>
    <name>TDottedFillStyle</name>
    <message>
        <source>Polka Dots</source>
        <translation>波尔卡圆点</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>圆点大小</translation>
    </message>
    <message>
        <source>Dot Distance</source>
        <translation>圆点距离</translation>
    </message>
</context>
<context>
    <name>TDottedLineStrokeStyle</name>
    <message>
        <source>Vanishing</source>
        <translation>衰减</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>淡入</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation>线段</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>淡出</translation>
    </message>
    <message>
        <source>Gap</source>
        <translation>间隙</translation>
    </message>
</context>
<context>
    <name>TDualColorStrokeStyle2</name>
    <message>
        <source>Striped</source>
        <translation>条纹</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
</context>
<context>
    <name>TFriezeStrokeStyle2</name>
    <message>
        <source>Curl</source>
        <translation>卷缩</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>卷曲</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>TFurStrokeStyle</name>
    <message>
        <source>Herringbone</source>
        <translation>人字形</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>TGraphicPenStrokeStyle</name>
    <message>
        <source>Dashes</source>
        <translation>长划线</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
</context>
<context>
    <name>TLinGradFillStyle</name>
    <message>
        <source>Linear Gradient</source>
        <translation>线性渐变</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>水平位置</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>垂直位置</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>平滑度</translation>
    </message>
</context>
<context>
    <name>TLongBlendStrokeStyle2</name>
    <message>
        <source>Watercolor</source>
        <translation>水彩画</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
</context>
<context>
    <name>TMatrioskaStrokeStyle</name>
    <message>
        <source>Toothpaste</source>
        <translation>牙膏</translation>
    </message>
    <message>
        <source>Stripes</source>
        <translation>条纹</translation>
    </message>
</context>
<context>
    <name>TMosaicFillStyle</name>
    <message>
        <source>Stained Glass</source>
        <translation>花窗玻璃</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>扭曲</translation>
    </message>
    <message>
        <source>Min Thick</source>
        <translation>最小厚度</translation>
    </message>
    <message>
        <source>Max Thick</source>
        <translation>最大厚度</translation>
    </message>
</context>
<context>
    <name>TMultiLineStrokeStyle2</name>
    <message>
        <source>Gouache</source>
        <translation>水粉画</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>粗细</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>杂色</translation>
    </message>
</context>
<context>
    <name>TNoColorRasterStyle</name>
    <message>
        <source>Markup</source>
        <translation>标记</translation>
    </message>
</context>
<context>
    <name>TNormal2StrokeStyle</name>
    <message>
        <source>Bump</source>
        <translation>凸起</translation>
    </message>
    <message>
        <source>Light X Pos</source>
        <translation>光源水平位置</translation>
    </message>
    <message>
        <source>Light Y Pos</source>
        <translation>光源垂直位置</translation>
    </message>
    <message>
        <source>Shininess</source>
        <translation>光泽度</translation>
    </message>
    <message>
        <source>Plastic</source>
        <translation>塑料</translation>
    </message>
</context>
<context>
    <name>TPatchFillStyle</name>
    <message>
        <source>Beehive</source>
        <translation>蜂巢</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>扭曲</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>粗细</translation>
    </message>
</context>
<context>
    <name>TPointShadowFillStyle</name>
    <message>
        <source>Sponge Shading</source>
        <translation>海绵着色</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Point Size</source>
        <translation>点的大小</translation>
    </message>
</context>
<context>
    <name>TRadGradFillStyle</name>
    <message>
        <source>Radial Gradient</source>
        <translation>径向渐变</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>水平位置</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>垂直位置</translation>
    </message>
    <message>
        <source>Radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>平滑度</translation>
    </message>
</context>
<context>
    <name>TRopeStrokeStyle</name>
    <message>
        <source>Rope</source>
        <translation>绳索</translation>
    </message>
    <message>
        <source>Tilt</source>
        <translation>倾斜</translation>
    </message>
</context>
<context>
    <name>TRubberFillStyle</name>
    <message>
        <source>Blob</source>
        <translation>斑点</translation>
    </message>
    <message>
        <source>Intensity</source>
        <translation>强度</translation>
    </message>
</context>
<context>
    <name>TSawToothStrokeStyle</name>
    <message>
        <source>Jagged</source>
        <translation>锯齿状</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
</context>
<context>
    <name>TSinStrokeStyle</name>
    <message>
        <source>Wave</source>
        <translation>波形</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>频率</translation>
    </message>
</context>
<context>
    <name>TSketchStrokeStyle</name>
    <message>
        <source>Fuzz</source>
        <translation>绒毛</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
</context>
<context>
    <name>TSprayStrokeStyle</name>
    <message>
        <source>Circlets</source>
        <translation>小圆圈</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>边界淡化</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>TStripeFillStyle</name>
    <message>
        <source>Banded</source>
        <translation>带状</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>TTissueStrokeStyle</name>
    <message>
        <source>Gauze</source>
        <translation>纱网</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Border Size</source>
        <translation>边界大小</translation>
    </message>
</context>
<context>
    <name>TTwirlStrokeStyle</name>
    <message>
        <source>Ribbon</source>
        <translation>丝带</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>卷曲</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>阴影</translation>
    </message>
</context>
<context>
    <name>TZigzTSinStrokeStyleagStrokeStyle</name>
    <message>
        <source>Thickness</source>
        <translation>粗细</translation>
    </message>
</context>
<context>
    <name>TZigzagStrokeStyle</name>
    <message>
        <source>Zigzag</source>
        <translation>水波</translation>
    </message>
    <message>
        <source>Min Distance</source>
        <translation>最小距离</translation>
    </message>
    <message>
        <source>Max Distance</source>
        <translation>最大距离</translation>
    </message>
    <message>
        <source>Min Angle</source>
        <translation>最小角度</translation>
    </message>
    <message>
        <source>Max Angle</source>
        <translation>最大角度</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>粗细</translation>
    </message>
</context>
</TS>
